"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactRedux = require("react-redux");

var _lodash = _interopRequireDefault(require("lodash"));

var _Checkbox = _interopRequireDefault(require("../checkboxs/Checkbox"));

var _IconButton = _interopRequireDefault(require("@material-ui/core/IconButton"));

var _Add = _interopRequireDefault(require("@material-ui/icons/Add"));

var _SearchableSelect = _interopRequireDefault(require("../selects/SearchableSelect"));

require("./style.scss");

var _ConditionItem = _interopRequireDefault(require("./ConditionItem"));

var _Button = _interopRequireDefault(require("@material-ui/core/Button"));

var _jsxFileName = "/var/www/html/formbuilder/src/utils/conditional-logic/index.js";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var conditionalLabel = {
  en: 'Enable Conditional Logic',
  ar: 'تمكين المنطق الشرطي'
};

function ConditionalLogic(props) {
  var _this = this;

  var conditionalLogic = _lodash["default"].cloneDeep(props.conditionalLogic);

  var singleFields = [];
  var multiFields = [];
  var textFields = [];
  var numberFields = [];
  var fields = [];

  var extractOptionsFromPredefined = function extractOptionsFromPredefined(referenceId, options) {
    if (referenceId) {
      for (var i = 0; i < props.predefined.length; i++) {
        if (props.predefined[i].id === referenceId) {
          return props.predefined[i].options;
        }
      }
    }

    return options;
  };

  var getOptions = function getOptions() {
    var options = {};

    var allFields = _extends({}, props.conditionableFields, {}, props.data);

    _lodash["default"].map(allFields, function (field, uuid) {
      if (field.type === 'select') {
        if (field.config.isMultiple) {
          multiFields.push(field.machineName);
        } else {
          singleFields.push(field.machineName);
        }

        fields.push(field);
        options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'radio') {
        singleFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'checkbox') {
        multiFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'text') {
        if (field.config.subType === 'number') {
          numberFields.push(field.machineName);
          fields.push(field);
        } else {
          textFields.push(field.machineName);
          fields.push(field);
        }
      }
    });

    return options;
  };

  var _handleChange = function handleChange(val, name) {
    var _extends2;

    props.handleChange(_extends({}, props.conditionalLogic, (_extends2 = {}, _extends2[name] = val, _extends2)), 'conditionalLogic');
  };

  var enableConditionalLogic = function enableConditionalLogic(val) {
    props.handleChange(val, 'isConditionalEnabled');

    if (!val) {
      props.handleChange(_extends({}, props.conditionalLogic, {
        conditions: []
      }), 'conditionalLogic');
    }
  };

  var handleConditionChange = function handleConditionChange(val, index) {
    var conditions = _lodash["default"].cloneDeep(props.conditionalLogic.conditions);

    conditions[index] = val;
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var addCondition = function addCondition() {
    var conditions = _lodash["default"].cloneDeep(props.conditionalLogic.conditions);

    conditions.push({
      field: null,
      operator: 'contain',
      value: ''
    });
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var _deleteCondition = function deleteCondition(index) {
    var conditions = _lodash["default"].cloneDeep(props.conditionalLogic.conditions);

    conditions.splice(index);
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var renderConditions = function renderConditions() {
    var options = getOptions();

    if (conditionalLogic.conditions.length) {
      return conditionalLogic.conditions.map(function (condition, index) {
        var errors = props.errors[index] ? props.errors[index] : {};
        return /*#__PURE__*/_react["default"].createElement(_ConditionItem["default"], {
          key: index,
          errors: errors,
          index: index,
          handleChange: function handleChange(val) {
            return handleConditionChange(val, index);
          },
          deleteCondition: function deleteCondition(e) {
            return _deleteCondition(index);
          },
          fields: fields,
          condition: condition,
          multiFields: multiFields,
          singleFields: singleFields,
          textFields: textFields,
          numberFields: numberFields,
          options: options,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 123,
            columnNumber: 11
          }
        });
      });
    } else {
      return /*#__PURE__*/_react["default"].createElement("div", {
        className: "ahfb-width-full ahfb-py-3 ahfb-text-center",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 128,
          columnNumber: 9
        }
      }, /*#__PURE__*/_react["default"].createElement("p", {
        className: "ahfb-text-muted",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 129,
          columnNumber: 11
        }
      }, "Click below to add condition."));
    }
  };

  if (props.isConditionalEnabled) {
    return /*#__PURE__*/_react["default"].createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 137,
        columnNumber: 7
      }
    }, /*#__PURE__*/_react["default"].createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 138,
        columnNumber: 9
      }
    }, /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: "Enable Conditional Logic",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 139,
        columnNumber: 11
      }
    })), /*#__PURE__*/_react["default"].createElement("div", {
      className: "ahfb-d-flow-root",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 141,
        columnNumber: 9
      }
    }, /*#__PURE__*/_react["default"].createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mr-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 142,
        columnNumber: 11
      }
    }, /*#__PURE__*/_react["default"].createElement(_SearchableSelect["default"], {
      value: props.conditionalLogic.display,
      handleChange: function handleChange(e) {
        return _handleChange(e.target.value, 'display');
      },
      options: [{
        label: 'Show',
        value: 'show'
      }, {
        label: 'Hide',
        value: 'hide'
      }],
      disableClearable: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 142,
        columnNumber: 87
      }
    })), /*#__PURE__*/_react["default"].createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 143,
        columnNumber: 11
      }
    }, " this field if "), /*#__PURE__*/_react["default"].createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mx-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 144,
        columnNumber: 11
      }
    }, /*#__PURE__*/_react["default"].createElement(_SearchableSelect["default"], {
      value: props.conditionalLogic.logic,
      handleChange: function handleChange(e) {
        return _handleChange(e.target.value, 'logic');
      },
      options: [{
        label: 'All',
        value: 'all'
      }, {
        label: 'Any',
        value: 'any'
      }],
      disableClearable: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 144,
        columnNumber: 87
      }
    })), /*#__PURE__*/_react["default"].createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 145,
        columnNumber: 11
      }
    }, " of the following match:")), /*#__PURE__*/_react["default"].createElement("div", {
      className: "ahfb-mt-2",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 147,
        columnNumber: 9
      }
    }, renderConditions(), /*#__PURE__*/_react["default"].createElement("div", {
      className: "ahfb-clearfix",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 149,
        columnNumber: 11
      }
    }, /*#__PURE__*/_react["default"].createElement(_Button["default"], {
      onClick: addCondition,
      color: "primary",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 150,
        columnNumber: 13
      }
    }, /*#__PURE__*/_react["default"].createElement(_Add["default"], {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 150,
        columnNumber: 60
      }
    }), " ", conditionalLogic.conditions.length ? 'Add another condition' : 'Add condition'))));
  } else {
    return /*#__PURE__*/_react["default"].createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 157,
        columnNumber: 7
      }
    }, /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: conditionalLabel[props.currentLang],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 158,
        columnNumber: 9
      }
    }));
  }
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    data: state.form.data,
    conditionableFields: state.form.conditionableFields,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

var _default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(ConditionalLogic);

exports["default"] = _default;
module.exports = exports.default;